@@ -251,14 +251,12 @@ static void parse_arguments(int argc, char **argv);
 static void print_help(char *prog);
 static void time_update();
 static Bool raise_alarm();
-static Bool fexist(const char *filename);
 static Bool filestat(const char *filename, time_t *time, int mode);
 static int  my_system(char *cmd, char *opt);
 void *xmalloc(size_t size);
 char *xstrdup(const char *string);
 static void alrm_add(Alarm **list, const char *value);
 static void free_alrm(Alarm **list);
-static int nb_alrm(Alarm *list);
 static Bool alarms_on(Alarm *list);
 static void switch_alarms(Alarm *list);
 static Bool getbool(char *value);
@@ -271,9 +269,6 @@ static void reload_alarms();
 static void show_cal_file(int type);
 static void show_cal();
 static char *robust_home();
-static void signal_reload();
-
-
 
 int main(int argc, char **argv) {
     XEvent event;
@@ -1326,17 +1321,6 @@ static Bool raise_alarm() {
     return False;
 }
 
-
-static Bool fexist(const char *filename) {
-    FILE           *file;
-
-    if ((file = fopen(filename, "r")) == NULL) return False;
-    fclose(file);
-
-    return True;
-}
-
-
 static Bool filestat(const char *filename, time_t *time, int mode) {
     struct stat s;
     time_t      t = *time;
@@ -1471,17 +1455,6 @@ static void free_alrm(Alarm **list) {
 }
 
 
-static int nb_alrm(Alarm *list) {
-    Alarm *alrm = list;
-    int      n = 0;
-    while (alrm) {
-        n++;
-        alrm = alrm->next;
-    }
-    return n;
-}
-
-
 static Bool alarms_on(Alarm *list) {
     Alarm *alrm = list;
 
